require "uri"

module TelecomsCloud
  class VApi
    attr_accessor :api_client

    def initialize(api_client = ApiClient.default)
      @api_client = api_client
    end

    # Account Info
    # Provides account information
    # @param [Hash] opts the optional parameters
    # @return [AccountInfoResponseModel]
    def account_info(opts = {})
      data, status_code, headers = account_info_with_http_info(opts)
      return data
    end

    # Account Info
    # Provides account information
    # @param [Hash] opts the optional parameters
    # @return [Array<(AccountInfoResponseModel, Fixnum, Hash)>] AccountInfoResponseModel data, response status code and response headers
    def account_info_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#account_info ..."
      end
      
      # resource path
      path = "/v1/account/info".sub('{format}','json')

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'AccountInfoResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#account_info\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Request an access token using client credentials
    # Request an access token using client credentials. The returned access token can be used to make authenticated requests to any endpoint.
    # @param create_grant_client client_id : string - Unique client ID as issued by service provider. May be passed in query, body or along with client_secret in a basic auth header. client_secret : string - Client secret as issued by service provider. May be passed in json body or along with client_id in a basic auth header.
    # @param [Hash] opts the optional parameters
    # @return [ClientGrantResponseModel]
    def create_grant_client(create_grant_client, opts = {})
      data, status_code, headers = create_grant_client_with_http_info(create_grant_client, opts)
      return data
    end

    # Request an access token using client credentials
    # Request an access token using client credentials. The returned access token can be used to make authenticated requests to any endpoint.
    # @param create_grant_client client_id : string - Unique client ID as issued by service provider. May be passed in query, body or along with client_secret in a basic auth header. client_secret : string - Client secret as issued by service provider. May be passed in json body or along with client_id in a basic auth header.
    # @param [Hash] opts the optional parameters
    # @return [Array<(ClientGrantResponseModel, Fixnum, Hash)>] ClientGrantResponseModel data, response status code and response headers
    def create_grant_client_with_http_info(create_grant_client, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#create_grant_client ..."
      end
      
      # verify the required parameter 'create_grant_client' is set
      fail "Missing the required parameter 'create_grant_client' when calling create_grant_client" if create_grant_client.nil?
      
      # resource path
      path = "/v1/authorization/oauth2/grant-client".sub('{format}','json')

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = ['application/json']
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = @api_client.object_to_http_body(create_grant_client)
      

      auth_names = []
      data, status_code, headers = @api_client.call_api(:POST, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'ClientGrantResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#create_grant_client\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Received Fax Info
    # Provides received fax information including the faxes Id which can be used to download the fax document and a &#39;pointer&#39;. Make an initial request with the last_pointer parameter set to 0 (zero), this will return any items received within the last 48 hours, or an empty array if no items have been received. Each item record returned will include a &#39;pointer&#39;, to get updates received after the last check, pass the highest pointer seen.
    # @param last_pointer Latest known pointer, faxes records received after this will be returned. Enter 0 if unknown or no previous pointer..
    # @param [Hash] opts the optional parameters
    # @return [FaxInfoCollectionResponseModel]
    def retrieve_info(last_pointer, opts = {})
      data, status_code, headers = retrieve_info_with_http_info(last_pointer, opts)
      return data
    end

    # Received Fax Info
    # Provides received fax information including the faxes Id which can be used to download the fax document and a &#39;pointer&#39;. Make an initial request with the last_pointer parameter set to 0 (zero), this will return any items received within the last 48 hours, or an empty array if no items have been received. Each item record returned will include a &#39;pointer&#39;, to get updates received after the last check, pass the highest pointer seen.
    # @param last_pointer Latest known pointer, faxes records received after this will be returned. Enter 0 if unknown or no previous pointer..
    # @param [Hash] opts the optional parameters
    # @return [Array<(FaxInfoCollectionResponseModel, Fixnum, Hash)>] FaxInfoCollectionResponseModel data, response status code and response headers
    def retrieve_info_with_http_info(last_pointer, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#retrieve_info ..."
      end
      
      # verify the required parameter 'last_pointer' is set
      fail "Missing the required parameter 'last_pointer' when calling retrieve_info" if last_pointer.nil?
      
      # resource path
      path = "/v1/fax/inbound/info".sub('{format}','json')

      # query parameters
      query_params = {}
      query_params[:'last_pointer'] = last_pointer

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'FaxInfoCollectionResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#retrieve_info\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # 
    # Retrieve fax
    # @param id ID
    # @param [Hash] opts the optional parameters
    # @return [nil]
    def retrieve_fax(id, opts = {})
      retrieve_fax_with_http_info(id, opts)
      return nil
    end

    # 
    # Retrieve fax
    # @param id ID
    # @param [Hash] opts the optional parameters
    # @return [Array<(nil, Fixnum, Hash)>] nil, response status code and response headers
    def retrieve_fax_with_http_info(id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#retrieve_fax ..."
      end
      
      # verify the required parameter 'id' is set
      fail "Missing the required parameter 'id' when calling retrieve_fax" if id.nil?
      
      # resource path
      path = "/v1/fax/inbound/{id}".sub('{format}','json').sub('{' + 'id' + '}', id.to_s)

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = []
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#retrieve_fax\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Submit a fax for sending
    # Post a PDF file as fax_document. Returns unique id.
    # @param to Number to send fax to.
    # @param from Recipient will receive the message as sent from this number, accepts E.164 numbers (with leading &#39;+&#39;) or UK based number formatting by default.
    # @param fax_document Single PDF containing page(s) to be faxed.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :number_format_location Optional; ISO 3166-1 alpha-2 Two letter country code matching the location matching the provided number format, defaults to GB.
    # @return [FaxOutboundSendResponseModel]
    def send_fax(to, from, fax_document, opts = {})
      data, status_code, headers = send_fax_with_http_info(to, from, fax_document, opts)
      return data
    end

    # Submit a fax for sending
    # Post a PDF file as fax_document. Returns unique id.
    # @param to Number to send fax to.
    # @param from Recipient will receive the message as sent from this number, accepts E.164 numbers (with leading &#39;+&#39;) or UK based number formatting by default.
    # @param fax_document Single PDF containing page(s) to be faxed.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :number_format_location Optional; ISO 3166-1 alpha-2 Two letter country code matching the location matching the provided number format, defaults to GB.
    # @return [Array<(FaxOutboundSendResponseModel, Fixnum, Hash)>] FaxOutboundSendResponseModel data, response status code and response headers
    def send_fax_with_http_info(to, from, fax_document, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#send_fax ..."
      end
      
      # verify the required parameter 'to' is set
      fail "Missing the required parameter 'to' when calling send_fax" if to.nil?
      
      # verify the required parameter 'from' is set
      fail "Missing the required parameter 'from' when calling send_fax" if from.nil?
      
      # verify the required parameter 'fax_document' is set
      fail "Missing the required parameter 'fax_document' when calling send_fax" if fax_document.nil?
      
      # resource path
      path = "/v1/fax/outbound".sub('{format}','json')

      # query parameters
      query_params = {}
      query_params[:'to'] = to
      query_params[:'from'] = from
      query_params[:'numberFormatLocation'] = opts[:'number_format_location'] if opts[:'number_format_location']

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = ['multipart/form-data']
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}
      form_params["fax_document"] = fax_document

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:POST, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'FaxOutboundSendResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#send_fax\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Get fax submission status updates
    # Retrieve any status updates for fax submissions since last checked.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :last_pointer Optional pointer, if not used last two days will be returned.
    # @return [FaxOutboundGetUpdatesCollectionResponseModel]
    def retrieve_fax_updates(opts = {})
      data, status_code, headers = retrieve_fax_updates_with_http_info(opts)
      return data
    end

    # Get fax submission status updates
    # Retrieve any status updates for fax submissions since last checked.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :last_pointer Optional pointer, if not used last two days will be returned.
    # @return [Array<(FaxOutboundGetUpdatesCollectionResponseModel, Fixnum, Hash)>] FaxOutboundGetUpdatesCollectionResponseModel data, response status code and response headers
    def retrieve_fax_updates_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#retrieve_fax_updates ..."
      end
      
      # resource path
      path = "/v1/fax/outbound/updates".sub('{format}','json')

      # query parameters
      query_params = {}
      query_params[:'last_pointer'] = opts[:'last_pointer'] if opts[:'last_pointer']

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'FaxOutboundGetUpdatesCollectionResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#retrieve_fax_updates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Check the status of a submitted fax.
    # Returns the status of the fax submission referenced by the passed Id
    # @param id Id of message to check as provided on submission of Fax.
    # @param [Hash] opts the optional parameters
    # @return [FaxOutboundGetStatusResponseModel]
    def retrieve_fax_status(id, opts = {})
      data, status_code, headers = retrieve_fax_status_with_http_info(id, opts)
      return data
    end

    # Check the status of a submitted fax.
    # Returns the status of the fax submission referenced by the passed Id
    # @param id Id of message to check as provided on submission of Fax.
    # @param [Hash] opts the optional parameters
    # @return [Array<(FaxOutboundGetStatusResponseModel, Fixnum, Hash)>] FaxOutboundGetStatusResponseModel data, response status code and response headers
    def retrieve_fax_status_with_http_info(id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#retrieve_fax_status ..."
      end
      
      # verify the required parameter 'id' is set
      fail "Missing the required parameter 'id' when calling retrieve_fax_status" if id.nil?
      
      # resource path
      path = "/v1/fax/outbound/{id}/status".sub('{format}','json').sub('{' + 'id' + '}', id.to_s)

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'FaxOutboundGetStatusResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#retrieve_fax_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Get E.164 format number
    # Provides an E.164 formatted (e.g. +441514962245) version of the provided national (e.g. 01514962245) format phone number
    # @param number National format phone number (e.g. 01514962245).
    # @param location Two letter country code matching the location the provided number is formatted for (e.g. US).
    # @param [Hash] opts the optional parameters
    # @option opts [String] :pretty Optional query parameter. If true, returned number will contain whitespace for readability (e.g. +44 151 496 2245).
    # @return [NumberFormatterResponseModel]
    def format_e164(number, location, opts = {})
      data, status_code, headers = format_e164_with_http_info(number, location, opts)
      return data
    end

    # Get E.164 format number
    # Provides an E.164 formatted (e.g. +441514962245) version of the provided national (e.g. 01514962245) format phone number
    # @param number National format phone number (e.g. 01514962245).
    # @param location Two letter country code matching the location the provided number is formatted for (e.g. US).
    # @param [Hash] opts the optional parameters
    # @option opts [String] :pretty Optional query parameter. If true, returned number will contain whitespace for readability (e.g. +44 151 496 2245).
    # @return [Array<(NumberFormatterResponseModel, Fixnum, Hash)>] NumberFormatterResponseModel data, response status code and response headers
    def format_e164_with_http_info(number, location, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#format_e164 ..."
      end
      
      # verify the required parameter 'number' is set
      fail "Missing the required parameter 'number' when calling format_e164" if number.nil?
      
      # verify the required parameter 'location' is set
      fail "Missing the required parameter 'location' when calling format_e164" if location.nil?
      
      # resource path
      path = "/v1/format/number/e164/{number}/{location}".sub('{format}','json').sub('{' + 'number' + '}', number.to_s).sub('{' + 'location' + '}', location.to_s)

      # query parameters
      query_params = {}
      query_params[:'pretty'] = opts[:'pretty'] if opts[:'pretty']

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'NumberFormatterResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#format_e164\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Get international format number
    # Converts the provided National format number (e.g. 01514962245) into an dialable number in the provided location (e.g. 011441514962245 for dialing GB from US)
    # @param number Phone number in National format (e.g. 01514962245).
    # @param provided_location Two letter country code matching provided number format (e.g. GB).
    # @param dial_from_location Two letter country code of location dialling from (e.g. US).
    # @param [Hash] opts the optional parameters
    # @option opts [String] :pretty Optional query parameter. If true, returned number will contain whitespace for readability (e.g. 011 44 151 496 2245).
    # @return [NumberFormatterResponseModel]
    def format_international(number, provided_location, dial_from_location, opts = {})
      data, status_code, headers = format_international_with_http_info(number, provided_location, dial_from_location, opts)
      return data
    end

    # Get international format number
    # Converts the provided National format number (e.g. 01514962245) into an dialable number in the provided location (e.g. 011441514962245 for dialing GB from US)
    # @param number Phone number in National format (e.g. 01514962245).
    # @param provided_location Two letter country code matching provided number format (e.g. GB).
    # @param dial_from_location Two letter country code of location dialling from (e.g. US).
    # @param [Hash] opts the optional parameters
    # @option opts [String] :pretty Optional query parameter. If true, returned number will contain whitespace for readability (e.g. 011 44 151 496 2245).
    # @return [Array<(NumberFormatterResponseModel, Fixnum, Hash)>] NumberFormatterResponseModel data, response status code and response headers
    def format_international_with_http_info(number, provided_location, dial_from_location, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#format_international ..."
      end
      
      # verify the required parameter 'number' is set
      fail "Missing the required parameter 'number' when calling format_international" if number.nil?
      
      # verify the required parameter 'provided_location' is set
      fail "Missing the required parameter 'provided_location' when calling format_international" if provided_location.nil?
      
      # verify the required parameter 'dial_from_location' is set
      fail "Missing the required parameter 'dial_from_location' when calling format_international" if dial_from_location.nil?
      
      # resource path
      path = "/v1/format/number/international/{number}/{providedLocation}/{dialFromLocation}".sub('{format}','json').sub('{' + 'number' + '}', number.to_s).sub('{' + 'providedLocation' + '}', provided_location.to_s).sub('{' + 'dialFromLocation' + '}', dial_from_location.to_s)

      # query parameters
      query_params = {}
      query_params[:'pretty'] = opts[:'pretty'] if opts[:'pretty']

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'NumberFormatterResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#format_international\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Get national format number
    # Provides the national (e.g. 01514962245) format variant of the provided E.164 (e.g. +441514962245)
    # @param number Phone number in E.164 format (e.g. +441514962245).
    # @param location Two letter country code (e.g. US).
    # @param [Hash] opts the optional parameters
    # @option opts [String] :pretty Optional query parameter. If true, returned number will contain whitespace for readability (e.g. 0151 496 2245).
    # @return [NumberFormatterResponseModel]
    def format_national(number, location, opts = {})
      data, status_code, headers = format_national_with_http_info(number, location, opts)
      return data
    end

    # Get national format number
    # Provides the national (e.g. 01514962245) format variant of the provided E.164 (e.g. +441514962245)
    # @param number Phone number in E.164 format (e.g. +441514962245).
    # @param location Two letter country code (e.g. US).
    # @param [Hash] opts the optional parameters
    # @option opts [String] :pretty Optional query parameter. If true, returned number will contain whitespace for readability (e.g. 0151 496 2245).
    # @return [Array<(NumberFormatterResponseModel, Fixnum, Hash)>] NumberFormatterResponseModel data, response status code and response headers
    def format_national_with_http_info(number, location, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#format_national ..."
      end
      
      # verify the required parameter 'number' is set
      fail "Missing the required parameter 'number' when calling format_national" if number.nil?
      
      # verify the required parameter 'location' is set
      fail "Missing the required parameter 'location' when calling format_national" if location.nil?
      
      # resource path
      path = "/v1/format/number/national/{number}/{location}".sub('{format}','json').sub('{' + 'number' + '}', number.to_s).sub('{' + 'location' + '}', location.to_s)

      # query parameters
      query_params = {}
      query_params[:'pretty'] = opts[:'pretty'] if opts[:'pretty']

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'NumberFormatterResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#format_national\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Get pretty number
    # Uses whitespace to provide human readable numbers
    # @param number Phone number to format (e.g. 01514962245, 011441514962245, +441514962245).
    # @param location Two letter country code matching provided number format (e.g. GB).
    # @param [Hash] opts the optional parameters
    # @return [NumberFormatterResponseModel]
    def format_pretty(number, location, opts = {})
      data, status_code, headers = format_pretty_with_http_info(number, location, opts)
      return data
    end

    # Get pretty number
    # Uses whitespace to provide human readable numbers
    # @param number Phone number to format (e.g. 01514962245, 011441514962245, +441514962245).
    # @param location Two letter country code matching provided number format (e.g. GB).
    # @param [Hash] opts the optional parameters
    # @return [Array<(NumberFormatterResponseModel, Fixnum, Hash)>] NumberFormatterResponseModel data, response status code and response headers
    def format_pretty_with_http_info(number, location, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#format_pretty ..."
      end
      
      # verify the required parameter 'number' is set
      fail "Missing the required parameter 'number' when calling format_pretty" if number.nil?
      
      # verify the required parameter 'location' is set
      fail "Missing the required parameter 'location' when calling format_pretty" if location.nil?
      
      # resource path
      path = "/v1/format/number/pretty/{number}/{location}".sub('{format}','json').sub('{' + 'number' + '}', number.to_s).sub('{' + 'location' + '}', location.to_s)

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'NumberFormatterResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#format_pretty\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # 
    # Retrieve locality info
    # @param phone_number Phone number
    # @param [Hash] opts the optional parameters
    # @return [LocalityInfoResponseModel]
    def retrieve_locality_info(phone_number, opts = {})
      data, status_code, headers = retrieve_locality_info_with_http_info(phone_number, opts)
      return data
    end

    # 
    # Retrieve locality info
    # @param phone_number Phone number
    # @param [Hash] opts the optional parameters
    # @return [Array<(LocalityInfoResponseModel, Fixnum, Hash)>] LocalityInfoResponseModel data, response status code and response headers
    def retrieve_locality_info_with_http_info(phone_number, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#retrieve_locality_info ..."
      end
      
      # verify the required parameter 'phone_number' is set
      fail "Missing the required parameter 'phone_number' when calling retrieve_locality_info" if phone_number.nil?
      
      # resource path
      path = "/v1/locality-lookup/{phoneNumber}".sub('{format}','json').sub('{' + 'phoneNumber' + '}', phone_number.to_s)

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'LocalityInfoResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#retrieve_locality_info\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Check Telephone Preference Service
    # Check if provided number is included in the Telephony Preference Service list. Returns true or false.
    # @param phone_number Phone number to lookup in E.164 format or national format according to numberFormatLocation.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :number_format_location Optional; ISO 3166-1 alpha-2 Two letter country code matching the origin of the provided number format, defaults to GB.
    # @return [nil]
    def retrieve_tps(phone_number, opts = {})
      retrieve_tps_with_http_info(phone_number, opts)
      return nil
    end

    # Check Telephone Preference Service
    # Check if provided number is included in the Telephony Preference Service list. Returns true or false.
    # @param phone_number Phone number to lookup in E.164 format or national format according to numberFormatLocation.
    # @param [Hash] opts the optional parameters
    # @option opts [String] :number_format_location Optional; ISO 3166-1 alpha-2 Two letter country code matching the origin of the provided number format, defaults to GB.
    # @return [Array<(nil, Fixnum, Hash)>] nil, response status code and response headers
    def retrieve_tps_with_http_info(phone_number, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#retrieve_tps ..."
      end
      
      # verify the required parameter 'phone_number' is set
      fail "Missing the required parameter 'phone_number' when calling retrieve_tps" if phone_number.nil?
      
      # resource path
      path = "/v1/recipient-preferences/tps/{phone_number}".sub('{format}','json').sub('{' + 'phone_number' + '}', phone_number.to_s)

      # query parameters
      query_params = {}
      query_params[:'numberFormatLocation'] = opts[:'number_format_location'] if opts[:'number_format_location']

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = []
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#retrieve_tps\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Send an SMS Text Message
    # Send an SMS message from one of your TC numbers, or the default number (this can be found on the API Access settings on the TelecomsCloud website). SMS message is queued for delivery to the specified recipient, returning a unique reference on success. This reference can be used to check the status of the submitted message.
    # @param sms_outbound_send_response_model * to : string (required) - Number to send message to.  * from : string (required) - Recipient will receive the message as sent from this number, accepts E.164 numbers (with leading &#39;+&#39;) or UK based number formatting by default.  * message : string (required) - Message to send to recipient, up to 160 chars.  * numberFormatLocation : string - Optional; ISO 3166-1 alpha-2 Two letter country code matching the location matching the provided number format, defaults to GB.
    # @param [Hash] opts the optional parameters
    # @return [SmsOutboundSendResponseModel]
    def send_sms(sms_outbound_send_response_model, opts = {})
      data, status_code, headers = send_sms_with_http_info(sms_outbound_send_response_model, opts)
      return data
    end

    # Send an SMS Text Message
    # Send an SMS message from one of your TC numbers, or the default number (this can be found on the API Access settings on the TelecomsCloud website). SMS message is queued for delivery to the specified recipient, returning a unique reference on success. This reference can be used to check the status of the submitted message.
    # @param sms_outbound_send_response_model * to : string (required) - Number to send message to.  * from : string (required) - Recipient will receive the message as sent from this number, accepts E.164 numbers (with leading &#39;+&#39;) or UK based number formatting by default.  * message : string (required) - Message to send to recipient, up to 160 chars.  * numberFormatLocation : string - Optional; ISO 3166-1 alpha-2 Two letter country code matching the location matching the provided number format, defaults to GB.
    # @param [Hash] opts the optional parameters
    # @return [Array<(SmsOutboundSendResponseModel, Fixnum, Hash)>] SmsOutboundSendResponseModel data, response status code and response headers
    def send_sms_with_http_info(sms_outbound_send_response_model, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#send_sms ..."
      end
      
      # verify the required parameter 'sms_outbound_send_response_model' is set
      fail "Missing the required parameter 'sms_outbound_send_response_model' when calling send_sms" if sms_outbound_send_response_model.nil?
      
      # resource path
      path = "/v1/sms/outbound".sub('{format}','json')

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = ['application/json']
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = @api_client.object_to_http_body(sms_outbound_send_response_model)
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:POST, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'SmsOutboundSendResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#send_sms\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # 
    # Get sms status
    # @param sms_id Sms ID
    # @param [Hash] opts the optional parameters
    # @return [SmsOutboundGetStatusResponseModel]
    def get_sms_status(sms_id, opts = {})
      data, status_code, headers = get_sms_status_with_http_info(sms_id, opts)
      return data
    end

    # 
    # Get sms status
    # @param sms_id Sms ID
    # @param [Hash] opts the optional parameters
    # @return [Array<(SmsOutboundGetStatusResponseModel, Fixnum, Hash)>] SmsOutboundGetStatusResponseModel data, response status code and response headers
    def get_sms_status_with_http_info(sms_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug "Calling API: VApi#get_sms_status ..."
      end
      
      # verify the required parameter 'sms_id' is set
      fail "Missing the required parameter 'sms_id' when calling get_sms_status" if sms_id.nil?
      
      # resource path
      path = "/v1/sms/outbound/{sms_id}/status".sub('{format}','json').sub('{' + 'sms_id' + '}', sms_id.to_s)

      # query parameters
      query_params = {}

      # header parameters
      header_params = {}

      # HTTP header 'Accept' (if needed)
      _header_accept = ['application/json']
      _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

      # HTTP header 'Content-Type'
      _header_content_type = []
      header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

      # form parameters
      form_params = {}

      # http body (model)
      post_body = nil
      

      auth_names = ['Default']
      data, status_code, headers = @api_client.call_api(:GET, path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'SmsOutboundGetStatusResponseModel')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: VApi#get_sms_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end
  end
end




